@@ -1,5 +1,4 @@
 import socket
-from typing import Union
 
 from plogger import logger
 
@@ -33,10 +32,12 @@ class SocketClient:
                 self.client = self.connect(timeout=self.connection_timeout)
             except ConnectionRefusedError as err:
                 self.logger.error(f'Cannot establish socket connection to {self.host}:{self.port}. {err}')
+                raise err
             except socket.gaierror as err:
                 self.logger.error(f'Check host and port format. {self.host}:{self.port}. {err}')
+                raise err
             except socket.timeout as err:
-                self.logger.error(f'{self.host}:{self.port} is unavailable within 7 sec. {err}')
+                self.logger.error(f'{self.host}:{self.port} is unavailable within {self.connection_timeout} sec. {err}')
                 raise err
 
     def __getattr__(self, attr):
@@ -44,7 +45,10 @@ class SocketClient:
         raise AttributeError(f'SocketClient does not have specific attribute "{attr}"')
 
     def __str__(self):
-        msg = f'[{self.host} {self._receive_all()}]'
+        msg = (f'Host: {self.host}\n'
+               f'Port: {self.port}\n'
+               f'Logger name: {self.logger.name}\n'
+               f'Connection timeout: {self.connection_timeout}')
         return msg
 
     def connect(self, timeout: int = None):
@@ -107,12 +111,10 @@ class SocketClient:
                 raise TimeoutError(error_msg)
         return status
 
-    def send_command(self, cmd: str = '', timeout: float = None):
+    def send_command(self, cmd: str = ''):
         """Send network command and receive response.
 
         :param cmd:
-        :param timeout: While reading from socket
-        :return:
         """
 
         command = self._encode_command(cmd)
@@ -121,7 +123,7 @@ class SocketClient:
 
         try:
             self.client.sendall(command)
-            response = self._receive_all(timeout)
+            response = self._receive_all()
 
             # Save the greeting message for the first time only
             if self.greeting is None:
@@ -132,29 +134,21 @@ class SocketClient:
             self.logger.error(f'{self.host:<14} | {err}')
             raise err
 
-    def _receive_all(self, timeout: Union[float, None] = None, buffer_size: int = 4096):
+    def _receive_all(self, buffer_size: int = 4096):
         """Get and decode socket response
 
-        :param timeout: Read timeout
-        :param buffer_size: 4096 by default
-        :return:
+        Args:
+            buffer_size: 4096 by default
         """
 
-        if timeout is None:
-            data = self.client.recv(buffer_size)
-        else:
-            self.client.settimeout(timeout)
-            data = bytearray()
+        data = bytearray()
 
-            try:
-                while True:
-                    chunk = self.client.recv(buffer_size)
-                    if not chunk:
-                        break
-                    data.extend(chunk)
-            except socket.timeout:
-                self.logger.warning(f'{self.host:<14} | <- Socket read timeout ({timeout})')
-                self.client.settimeout(None)  # Set blocking
+        while True:
+            chunk = self.client.recv(buffer_size)
+            data.extend(chunk)
+
+            if chunk.endswith(b'\r\n\r\n'):
+                break
 
         response = data.decode().strip().splitlines()
 
